# Chopper
CHOPPER_HOST = "10.98.162.175"
CHOPPER_PORT = 50051
FRAME_TIME_INTERVAL = 2
'''Number of frames to wait before capturing the next frame. Increasing this value will increase performance as less frames will be saved and thus processed later down the line.'''
# Processor
MODEL_SIZE = "s"
# Redis
REDIS_HOST = "10.108.148.45"
REDIS_PORT = 6379
# Minio
MINIO_HOST = "minio-proj.minio-ns.svc.cluster.local:9000"
MINIO_USER = "rootuser"
MINIO_PASSWORD = "rootpass123"
BUCKET_NAME = "eztopo-bucket"
# Rest 
REST_HOST = "10.109.150.175"
REST_PORT = 5000
# Web
WEB_HOST = "10.96.75.120"
WEB_PORT = 3000

INITIAL_UPLOAD = 0


